from time import sleep
import TimeTagger

# Create a TimeTagger instance to control your hardware
tagger = TimeTagger.createTimeTagger()

channels = [1, 3]

# This enables internal test signal for demo purposes.
# Uncomment the line below if you want to try this without external signals
#tagger.setTestSignal(channels, True)

# We create a Countrate instance, it will acquire data immediately
countrate = TimeTagger.Countrate(tagger=tagger, channels=channels)

# EXAMPLE 1 
# Periodically read and print the average countrate measured since measurement creation.
print('EXAMPLE 1. Infinite average.')
print('Average countrate values since the measurement creation.')
for i in range(10):
    # Wait for some time (software controlled)
    sleep(0.5)
    # Read countrate averaged over the run duration
    rate = countrate.getData()  
    # Read time since measurement start
    duration_of_measurement = countrate.getCaptureDuration()
    print(
        f'Average countrate: CH{channels[0]}: {rate[0]:10.6f} cps, '
        f'CH{channels[1]}:{rate[1]:10.6f} cps '
        f'@ averaged over: {duration_of_measurement*1e-12:0.3f} s'
    )


# EXAMPLE 2
# Periodically measure average countrate over well defined period of time.
average_time = 0.5 # seconds
print('EXAMPLE 2. Average over defined time.')
print('Average countrate values measured periodically over the defined time.')
for i in range(10):
    # Start the measurement for defined duration. It will stop automtically.
    countrate.startFor(average_time*1e12, clear=True)
    # Wait until the measurement averaged over the requested duration.
    countrate.waitUntilFinished()
    # Read countrate averaged over the run duration
    rate = countrate.getData()  
    # Read time since measurement start
    duration_of_measurement = countrate.getCaptureDuration()
    print(
        f'Average countrate: CH{channels[0]}: {rate[0]:10.6f} cps, '
        f'CH{channels[1]}:{rate[1]:10.6f} cps '
        f'@ averaged over: {duration_of_measurement*1e-12:0.3f} s'
    )


# At the end we close the connection to the Time Tagger
TimeTagger.freeTimeTagger(tagger)
